# MorphoNet


This is an API is used to interact with MorphoNet with python script.
You can find more help and tutorials on the MorphoNet website : http://www.morphonet.org

## Installation
This API work on python 3.7

### Recommandation

We recommend to use the python packages manager [pip](https://pypi.org/project/pip) ` apt-get install python-pip `

Install [imageio](https://pypi.org/project/imageio/) (for Image Handling)  using   `pip install imageio`

Install [scikit-image](https://pypi.org/project/scikit-image/) using   `pip install scikit-image`

Install [scipy](https://pypi.org/project/scipy/) using   `pip install scipy`

Install [vtk](https://pypi.org/project/vtk/) using   `pip install vtk`

You can now install the MorphoNet API using   `pip install morphonet`




